@@ -3,20 +3,20 @@
 set -e
 
 PKG=`dpkg-parsechangelog | awk '/^Source/ { print $2 }'`
-VERSION=`uscan --rename --verbose --force-download | 
-    grep "Newest version on remote site is .* local version is .*" | 
-    head -n 1 | 
-    sed "s/Newest version on remote site is \([a-z0-9.]\+\),.*/\1/"`
-
-#VERSION=`dpkg-parsechangelog | awk '/^Version/ { print $2 }'| cut -d"-" -f1`
+#VERSION=`uscan --rename --verbose --force-download | 
+#    grep "Newest version on remote site is .* local version is .*" | 
+#    head -n 1 | 
+#    sed "s/Newest version on remote site is \([a-z0-9.]\+\),.*/\1/"`
+uscan --rename --verbose --force-download
+VERSION=`dpkg-parsechangelog | awk '/^Version/ { print $2 }'| cut -d"-" -f1`
 #svn export  svn://scm.gforge.inria.fr/svn/logolexec/trunk/LogolExec ${PKG}-${VERSION}.orig
 
 mkdir -p ../tarballs
 cd ../tarballs
 
-UTAR="${PKG}_${VERSION}.orig.tar.xz"
+UTAR="${PKG}_${VERSION}.orig.tar.gz"
 mv ../${UTAR} .
-tar xfJ ${UTAR}
+tar xfz ${UTAR}
 
 mv ${PKG}-${VERSION} ${PKG}-${VERSION}.orig
 
